==> portal-transparencia-1.125.5.zip: BOOT-INF/classes/db/sql/contab/adiantamento.sql <==
 SELECT A.ENTIDADE,
        A.EXERCICIO,
    A.EMPENHO AS PRESTACAOCONTAS,
    F.NOME,
    A.DATA AS DATAPRESTACAO,
    E.EMPENHO,
    A.EXERCICIO AS EXERCICIOEMPENHO,
    E.DATA AS DATAEMPENHO,
    E.VALOR AS VALOREMPENHO,
        COALESCE((SELECT SUM(OL.VALOR) FROM ORDEMPAGAMENTO_LIQUIDACAO OL
                  WHERE A.ENTIDADE = OL.ENTIDADE
                    AND A.EXERCICIO = OL.ANODOCORIGEM
                    AND A.EMPENHO = OL.NODOCORIGEM
                    AND A.NOLIQUIDACAO = OL.NOLIQUIDACAO
                    AND A.UNIDADEORCAMENTARIA = OL.UNIDADEDOCORIGEM),0) AS VALORPAGO,
    COALESCE((SELECT SUM(DOC.VALOR) FROM PCADIANTAMENTODOC DOC
                 WHERE A.ENTIDADE = DOC.ENTIDADE
                   AND A.EXERCICIO = DOC.EXERCICIO
                   AND A.EMPENHO = DOC.EMPENHO
                   AND A.NOLIQUIDACAO = DOC.NOLIQUIDACAO
                   AND A.UNIDADEORCAMENTARIA = DOC.UNIDADEORCAMENTARIA
                   AND A.MATRICULA = DOC.MATRICULA),0) AS VALORDOCUMENTOS,
    0 AS VALORRESTITUIDOSUB, 
	0 AS VALORPRESTAR,
    CAST(' ' AS VARCHAR(10)) AS CARGO,
    CAST(' ' AS VARCHAR(10)) AS LOTACAO,
    A.UNIDADEORCAMENTARIA,
    A.NOLIQUIDACAO,
    A.MATRICULA,
    0 AS VALORRESTITUIDO, 	
    0 AS VALOREXCEDIDO,
	0 AS EMPENHOEXCEDIDO,
	0 AS EXERCICIOEMPENHOEXCEDIDO,
	0 AS RECEITAVALOR
 FROM PCADIANTAMENTO A
	 LEFT OUTER JOIN EMPENHO E
		ON A.ENTIDADE = E.ENTIDADE
		AND A.EXERCICIO = E.EXERCICIO
		AND A.EMPENHO = E.EMPENHO
		AND A.UNIDADEORCAMENTARIA = E.UNIDADEORCAMENTARIA 
	 LEFT OUTER JOIN FORNECEDOR F
		ON E.FORNECEDOR = F.FORNECEDOR
 WHERE A.EXERCICIO = :exercicio

==> portal-transparencia-3.22.1.zip: BOOT-INF/classes/db/sql/contab/adiantamento.sql <==
 SELECT A.ENTIDADE,
        A.EXERCICIO,
    A.EMPENHO AS PRESTACAOCONTAS,
    F.NOME,
    A.DATA AS DATAPRESTACAO,
    E.EMPENHO,
    A.EXERCICIO AS EXERCICIOEMPENHO,
    E.DATA AS DATAEMPENHO,
    E.VALOR AS VALOREMPENHO,
        COALESCE((SELECT SUM(OL.VALOR) FROM ${db.contabilidade.schema}.ORDEMPAGAMENTO_LIQUIDACAO OL
                  WHERE A.ENTIDADE = OL.ENTIDADE
                    AND A.EXERCICIO = OL.ANODOCORIGEM
                    AND A.EMPENHO = OL.NODOCORIGEM
                    AND A.NOLIQUIDACAO = OL.NOLIQUIDACAO
                    AND A.UNIDADEORCAMENTARIA = OL.UNIDADEDOCORIGEM),0) AS VALORPAGO,
    COALESCE((SELECT SUM(DOC.VALOR) FROM ${db.contabilidade.schema}.PCADIANTAMENTODOC DOC
                 WHERE A.ENTIDADE = DOC.ENTIDADE
                   AND A.EXERCICIO = DOC.EXERCICIO
                   AND A.EMPENHO = DOC.EMPENHO
                   AND A.NOLIQUIDACAO = DOC.NOLIQUIDACAO
                   AND A.UNIDADEORCAMENTARIA = DOC.UNIDADEORCAMENTARIA
                   AND A.MATRICULA = DOC.MATRICULA),0) AS VALORDOCUMENTOS,
    0 AS VALORRESTITUIDOSUB, 
	0 AS VALORPRESTAR,
    CAST(' ' AS VARCHAR(10)) AS CARGO,
    CAST(' ' AS VARCHAR(10)) AS LOTACAO,
    A.UNIDADEORCAMENTARIA,
    A.NOLIQUIDACAO,
    A.MATRICULA,
    0 AS VALORRESTITUIDO, 	
    0 AS VALOREXCEDIDO,
	0 AS EMPENHOEXCEDIDO,
	0 AS EXERCICIOEMPENHOEXCEDIDO,
	0 AS RECEITAVALOR
 FROM ${db.contabilidade.schema}.PCADIANTAMENTO A
	 LEFT OUTER JOIN ${db.contabilidade.schema}.EMPENHO E
		ON A.ENTIDADE = E.ENTIDADE
		AND A.EXERCICIO = E.EXERCICIO
		AND A.EMPENHO = E.EMPENHO
		AND A.UNIDADEORCAMENTARIA = E.UNIDADEORCAMENTARIA 
	 LEFT OUTER JOIN ${db.contabilidade.schema}.FORNECEDOR F
		ON E.FORNECEDOR = F.FORNECEDOR
 WHERE A.EXERCICIO = :exercicio
